package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````>!X```````!``````````)BA````
M````!0```$``.``*`$``%@`5``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```!P`@``````
M`'`"````````<`(````````:`````````!H``````````0`````````#``!P
M!````&R@`````````````````````````````&8````````````````````!
M``````````$````%````````````````````````````````````5)0`````
M``!4E``````````0`````````0````8```"XFP```````+BK````````N*L`
M``````"8!````````/`$`````````!`````````"````!@```,B;````````
MR*L```````#(JP```````.`!````````X`$````````(``````````0````$
M````C`(```````",`@```````(P"````````)``````````D``````````0`
M````````4.5T9`0```"`C0```````("-````````@(T```````#4````````
M`-0`````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$````N)L```````"X
MJP```````+BK````````2`0```````!(!`````````$`````````+VQI8B]L
M9"UM=7-L+7)I<V-V-C0N<V\N,0````0````4`````P```$=.50#KSXMW=G<B
M803&O)/K^CR8&+LK_Q$```!,````!`````@````@D!``!4`$@"@`$02`A@2$
M@H$``@D`!`B(@!!!N@`"B`````!,````3P```%(```!3````6@```%L```!<
M````7@```%\```!@````8@```&,```!D````9@``````````````SMY'+6[%
MWQ]K?YI\+L6;MB#_Y`[59-1\V7%8'+(!BV^83\.;PN4_+$+ZUX?ZH6Q@NN.2
M?.-'Q@%5PSS29Z_,9H@'<--#1=7L<U"?V#-BV^T^S])L%8PES/]A\F%_J9R;
MX*<""FL:GE"CX/M)``````````````````````````````````````,`"0#P
M'```````````````````D`(``!(`````````````````````````NP$``!(`
M````````````````````````8````!(`````````````````````````W`(`
M`!(`````````````````````````P0```!$`````````````````````````
MCP$``!(`````````````````````````1````!(`````````````````````
M````.0$``!(`````````````````````````^`$``!(`````````````````
M````````N````!(`````````````````````````TP```"(`````````````
M````````````6`$``!(`````````````````````````W0$``!(`````````
M````````````````?@(``!(`````````````````````````H`$``!(`````
M````````````````````'`$``!(`````````````````````````EP(``!(`
M````````````````````````YP(``"$`````````````````````````/@``
M`!(`````````````````````````Y@(``!$`````````````````````````
MT`$``!$`````````````````````````1P$``!(`````````````````````
M````2@0``"(`````````````````````````9P(``!(`````````````````
M````````<````!(`````````````````````````%P(``!(`````````````
M````````````Z`(``!$`````````````````````````J0```!(`````````
M````````````````/@(``!(`````````````````````````)@```"``````
M````````````````````;0$``!(`````````````````````````_0```"``
M````````````````````````Y0(``"$`````````````````````````>```
M`!(`````````````````````````%P$``!(`````````````````````````
M:````!(`````````````````````````60```!(`````````````````````
M````%P```!(`````````````````````````-0(``!(`````````````````
M````````K@(``!(`````````````````````````"0```!(`````````````
M````````````KP$``!(`````````````````````````AP```"``````````
M````````````````IP(``!(`````````````````````````5P(``!(`````
M````````````````````4@```!(`````````````````````````!`(``!(`
M`````````````````````````0```!(`````````````````````````2P``
M`!(`````````````````````````/@0``!(`````````````````````````
MQ`(``"(`````````````````````````20(``!(`````````````````````
M````GP(``!(`````````````````````````$````!$`````````````````
M````````)0(``!(`````````````````````````>0```!(`````````````
M````````````A0(``!(`````````````````````````'P```!(`````````
M````````````````(@$``!(`````````````````````````^````!(`````
M````````````````````?`$``!8`````````````````````````M0(``!(`
M````````````````````````R@(``!(`````````````````````````0`$`
M`!(`````````````````````````HP```!(`````````````````````````
ML0```!(`````````````````````````?@```!(`````````````````````
M````7P$``!(`````````````````````````<@(``!(`````````````````
M````````,P$``!(`````````````````````````X@```"``````````````
M````````````[@$``!(`````````````````````````J````!(`````````
M````````````````\P$``!(`````````````````````````JP,``!(`"0`N
M+0```````*H$````````N`,``!(`"0"@,P```````*0`````````UP(``!(`
M"0#P'````````(@!````````+P,``!(`"0"@)`````````(`````````9`,`
M`!(`"0"B)````````*8!````````>0,``!(`"0#8,0```````,@!````````
MT`,``!``$@!0L```````````````````2@,``!(`"0#.*@```````$X`````
M````<0,``!(`"0`<*P```````$8`````````CP,``!(`"0"4(P```````"@`
M````````H`,``!(`"0`Z20```````#(!````````W`,``!(`"0!R+```````
M`+P`````````&@0``!``$@"HL```````````````````'P0``!(`"0!()@``
M`````"(`````````EP,``!(`"0"0'@```````"(`````````6`,``!(`"0!J
M)@```````.0`````````0`,``!$`$0!(L`````````@`````````$P0``!``
M$0!0L```````````````````'P,``!``$0!0L```````````````````U0,`
M`!(`"0!X'@``````````````````!`0``!``$0``L```````````````````
M1P0``!(`"0#D2````````%8`````````Q`,``!``$@"HL```````````````
M````+`0``!(`"0!<+````````!8`````````[@,``!(`"0"\(P```````.0`
M````````4`0``!(`"0!L2@```````+0!````````$@,``!(`"0!.)P``````
M`(`#`````````&]P96YD:7(`;65M8VUP`'-T9&5R<@!R96%L;&]C`&%C8V5S
M<P!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E:P!G971P:60`<W1R8VUP
M`&UE;7-E=`!U;FQI;FL`;65M;6]V90!S=')N8VUP`'-T<G)C:'(`;'-T870`
M8VQO<V5D:7(`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`&]P96X`=F9P
M<FEN=&8`<W1R8VAR`')E861L:6YK`%]?<W1A8VM?8VAK7V=U87)D`%]?8WAA
M7V9I;F%L:7IE`%]?<F5G:7-T97)?9G)A;65?:6YF;P!E>&ET`%])5$U?<F5G
M:7-T97)434-L;VYE5&%B;&4`<F5A9`!R;61I<@!?7V5R<FYO7VQO8V%T:6]N
M`&UK9&ER`&UE;6-P>0!S=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`
M4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!03%]C=7)R96YT7V-O;G1E
M>'0`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S
M=@!097)L7V-R;V%K7VYO8V]N=&5X=`!03%]D;U]U;F1U;7``4&5R;%]N97=8
M4U]F;&%G<P!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL
M;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E
M<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P
M87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!S=')C<'D`<F5A
M9&1I<@!S<')I;G1F`'-T<F1U<`!S=')T;VL`<'1H<F5A9%]A=&9O<FL`7V9I
M;FD`7U]L:6)C7W-T87)T7VUA:6X`<VYP<FEN=&8`7U]?96YV:7)O;@!L:6)P
M97)L+G-O`&QI8F,N;75S;"UR:7-C=C8T+G-O+C$`<&%R7VEN:71?96YV`%]?
M4T1!5$%?0D5'24Y?7P!P87)?8W5R<F5N=%]E>&5C`&UY7W!A<E]P;`!P87)?
M96YV7V-L96%N`'!A<E]D:7)N86UE`'!A<E]F:6YD<')O9P!P87)?9&EE`%A3
M7TEN=&5R;F%L<U]005)?0D]/5`!X<U]I;FET`%]S=&%R=%]C`'-H85]U<&1A
M=&4`<&%R7VUK=&UP9&ER`'!A<E]C;&5A;G5P`%]?0E-37T5.1%]?`%]?8G-S
M7W-T87)T`'!A<E]S971U<%]L:6)P871H`'!A<E]C=7)R96YT7V5X96-?<')O
M8P!?7T1!5$%?0D5'24Y?7P!?961A=&$`7V5N9`!P87)?8F%S96YA;64`9V5T
M7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<VAA7VEN:70`<VAA7V9I;F%L`"]U
M<W(O;&EB+W!E<FPU+V-O<F5?<&5R;"]#3U)%`+BK`````````P````````!,
M'P```````,"K`````````P``````````'P```````-"O`````````P``````
M``#P'`````````"P`````````P``````````L````````!BP`````````P``
M``````!H30```````""P`````````P````````#03P```````"BP````````
M`P````````#83P```````#"P`````````P````````#@3P```````#BP````
M`````P````````#H3P```````$BP`````````P````````#P3P```````("O
M`````````@````8``````````````(BO`````````@````<`````````````
M`)"O`````````@````P``````````````)BO`````````@```!8`````````
M`````*"O`````````@```!@``````````````*BO`````````@```!P`````
M`````````+"O`````````@```!\``````````````+BO`````````@```"$`
M`````````````,"O`````````@```"P``````````````,BO`````````@``
M`"X``````````````-BO`````````@```#```````````````."O````````
M`@```#0``````````````.BO`````````@```#<``````````````/"O````
M````"P```#X``````````````/BO`````````@```$@``````````````+BM
M````````!0````(``````````````,"M````````!0````,`````````````
M`,BM````````!0````0``````````````-"M````````!0````4`````````
M`````-BM````````!0````@``````````````."M````````!0````D`````
M`````````.BM````````!0````H``````````````/"M````````!0````L`
M`````````````/BM````````!0````T```````````````"N````````!0``
M``X```````````````BN````````!0````\``````````````!"N````````
M!0```!```````````````!BN````````!0```!$``````````````""N````
M````!0```!(``````````````"BN````````!0```!0``````````````#"N
M````````!0```!<``````````````#BN````````!0```!D`````````````
M`$"N````````!0```!H``````````````$BN````````!0```!L`````````
M`````%"N````````!0```!T``````````````%BN````````!0```!X`````
M`````````&"N````````!0```"```````````````&BN````````!0```",`
M`````````````'"N````````!0```"0``````````````'BN````````!0``
M`"4``````````````("N````````!0```"8``````````````(BN````````
M!0```"<``````````````)"N````````!0```"@``````````````)BN````
M````!0```"D``````````````*"N````````!0```"H``````````````*BN
M````````!0```"L``````````````+"N````````!0```"T`````````````
M`+BN````````!0```"\``````````````,"N````````!0```#$`````````
M`````,BN````````!0```#(``````````````-"N````````!0```#,`````
M`````````-BN````````!0```#4``````````````."N````````!0```#8`
M`````````````.BN````````!0```#@``````````````/"N````````!0``
M`#D``````````````/BN````````!0```#H```````````````"O````````
M!0```#L```````````````BO````````!0```#P``````````````!"O````
M````!0```#T``````````````!BO````````!0```#\``````````````""O
M````````!0```$```````````````"BO````````!0```$$`````````````
M`#"O````````!0```$(``````````````#BO````````!0```$,`````````
M`````$"O````````!0```$0``````````````$BO````````!0```$4`````
M`````````%"O````````!0```$8``````````````%BO````````!0```$<`
M`````````````&"O````````!0```$D``````````````&BO````````!0``
M`$H``````````````'"O````````!0```$L`````````````````````````
MEY,``#,#PT$#OH-%$P-#_9."@T434Q,`@[*"`&<`#@`7G@```SZ.1&<##@`3
M````%YX```,^#D1G`PX`$P```!>>```#/HY#9P,.`!,````7G@```SX.0V<#
M#@`3````%YX```,^CD)G`PX`$P```!>>```#/@Y"9P,.`!,````7G@```SZ.
M06<##@`3````%YX```,^#D%G`PX`$P```!>>```#/HY`9P,.`!,````7G@``
M`SX.0&<##@`3````%YX```,^CC]G`PX`$P```!>>```#/@X_9P,.`!,````7
MG@```SZ./F<##@`3````%YX```,^#CYG`PX`$P```!>>```#/HX]9P,.`!,`
M```7G@```SX./6<##@`3````%YX```,^CCQG`PX`$P```!>>```#/@X\9P,.
M`!,````7G@```SZ..V<##@`3````%YX```,^#CMG`PX`$P```!>>```#/HXZ
M9P,.`!,````7G@```SX..F<##@`3````%YX```,^CCEG`PX`$P```!>>```#
M/@XY9P,.`!,````7G@```SZ..&<##@`3````%YX```,^#CAG`PX`$P```!>>
M```#/HXW9P,.`!,````7G@```SX.-V<##@`3````%YX```,^CC9G`PX`$P``
M`!>>```#/@XV9P,.`!,````7G@```SZ.-6<##@`3````%YX```,^#C5G`PX`
M$P```!>>```#/HXT9P,.`!,````7G@```SX.-&<##@`3````%YX```,^CC-G
M`PX`$P```!>>```#/@XS9P,.`!,````7G@```SZ.,F<##@`3````%YX```,^
M#C)G`PX`$P```!>>```#/HXQ9P,.`!,````7G@```SX.,6<##@`3````%YX`
M``,^CC!G`PX`$P```!>>```#/@XP9P,.`!,````7G@```SZ.+V<##@`3````
M%YX```,^#B]G`PX`$P```!>>```#/HXN9P,.`!,````7G@```SX.+F<##@`3
M````%YX```,^CBUG`PX`$P```!>>```#/@XM9P,.`!,````7G@```SZ.+&<#
M#@`3````%YX```,^#BQG`PX`$P```!>>```#/HXK9P,.`!,````7G@```SX.
M*V<##@`3````%YX```,^CBIG`PX`$P```!>>```#/@XJ9P,.`!,````7G@``
M`SZ.*6<##@`3````%YX```,^#BEG`PX`$P```!UQANRFY*J'HNC*X$[\EY0`
M`(.T)"@NZ#+D#`@P`&@(/LZ<8#[T@4?O\)_:%Y8```,VQBNRA1>5```#-24F
M[_`_\)>7``"#MV<F@\<'`.G/EY<``(.W!RL7E```$P0$-)*7F&-R28-'ITL;
M!4D`#@63YS<`(PWW2N_PG_/"91>6```#-J8M\D<#N`4`JH87-P``$P>G)!<U
M```3!:4CF.X4Y".P!@&(YI#J!4<-*6-6]PRA!1N%-P`11Y!ADQ<W`+:7!2>0
MXZ$%XQFG_@X'"&PVER,P!P!*A@%'EP4``).%!5?O\/_)/<4(;),)00+O\#_=
M*HG.A1<U```3!27Q[P!@&"G-"&SO\+_L[_!_Z2)WG&"YCP%'O>?F8$9DIF3B
M>4J%!FDE88*`[_"?W1>4```3!,0F".PAQ>_PG[^7EP``@[=''(5F,X='`!AC
M-I<C"P>6.;<(;._PO\UYMPAH`<7O$`!51;?.A1<U```3!87B[P!`$0CH6=7E
MMQ%'@;\%1>_P']OO\-^^EZ$``).!@9@*A9>5``"3A674$W$!_PF@#$$3!H4`
M@4<7EP```S>'%)>6``"#M@80%Y4```,UA1)!NQ>5```3!>49EY<``).'9QEC
MB*<`EY<``(.WIP^1PX*'@H`7E0``$P7%%Y>5``"3A447B8V3US5`_9&^E86%
MF<67EP``@[=G#)'#@H>"@)>7``"#QP<5J>-!$0;DEY<``(.W)PB1QQ>5```#
M-84.@I?O\!_YEY<``(.WIPB1QQ=U```3!87R@I>B8(5'%Y<``",)]Q!!`8*`
M@H"7EP``@[?'"IG/01$&Y)>5``"3A>4/%W4``!,%9>^"EZ)@00&5MXVW.7$&
M_"+X6N"7EP``@[?'`@.[!P!C`0L(2O!.[%+H@T<%`*J)+HHJB1,'T`.]PV.&
MYP"#1QD`!0G]^SL).4$#-`L`(<PF]%;DVH23"M`#2H;.A2*%[_"?LK,')`$)
MY8/'!P!C@%<#@&2A!'7PHG0">>)I0FJB:N)P(H5"=`)K(6&"@+.$9$&-A`4)
M(R":`$J4\;\!26VW`43YOP)YXFE":MF_<7$B\2;M!O67E```@[0D]BP`G&`^
MY8%'*H3O\!^J#>'B1[UF$6?UCV.%YP`I9V.:YP`BA8E%[_!?NQ,U%0`1H`%%
M*F><8+F/`4>1YZIP"G3J9$UA@H#O\%^?,7%*\0;]%YD```,YJ?"#-PD`/N6!
M1QG%(OF#1P4`*H2)[TIT*F>#-PD`N8\!1V.>!PSJ<`IY*6&"@";U[_!?K:J$
M3<U.[2:%[_"?F%')@T<U`9,)-0&;AR?]&X<'`)GC`\<9`&W3@T<U`9N')_T;
MAP<`@>N#QQD`FX<G_1N'!P"URW'3(H52Z>_PG[4JBDZ%[_`?M3L%J@`))>_P
M?Y#.AB*&ES4``).%Y;"JB>_P7ZHL`$Z%[_#?J_U78PCU`.)'O6819_6/8X[G
M`DZ%[_!?G$Z%[_#_N2:%2FKO\'^/)?DFA>_P_[(BA>_PGXU*=*ITZFD-OP/'
M*0`YUVFW2G2J=!6W3H7O\-_OX;<B^2;U3NU2Z>_P_XT=<:+HIN3*X(;L3OQ2
M^%;T6O`7F0```SF)W@/'!0"#-PD`/N2!1Y,'T`,NA*J$8Q3W`!.$%0`BA>_P
M/ZDJBDP`)H7O\-_:JHEIR>_P'ZAC=44+DDH7FP```SOKW(X*`\<$`*:'DP;0
M`V,*!Q)C!M<``\<7`(4'??N%GX,Y"P`3!2H`/I76F>_P7X`CL*D`*<6#-PL`
M`\<$`!.%%`#6EY1C$P;0`R.`Y@`!Z[6@`T<%``4%HX#G`"7#MH>%!N,8Q_X3
M!]`#(X#G`(4'`T<$``4$A0>CC^?^=?LB9X,W"0"YCP%'\>/F8$9DIF0&:>)Y
M0GJB>@)[)6&"@(-'!``%!(4)HX_Y_O';@T<$``4$A0FCC_G^_?/1M[:'9;=>
M[&+H%YL```,[2]`#/`L`@S<,`*W+XH>!29AGH0?.AH4I9?^-)I.5-@"7EP``
M@Z?GVQ>7```3!V?;E>N%1RZ%',/O\._RJHLQQ9.:.0#BA5:&[_#OZ2,P>P&;
MAQD`C@>^FR.P"P#B:T)L3L+AO6*%[_`?@",PJP"JBPG-DYHY`.F_@4?QO<%%
M@4E%MU[L8NCO\`_SXFM";!VW01$BX!>4```#-"3+!N27=@``DX:&H;,'1`"(
M8Q>6```#-B;'ES4``).%I8SO\*_T$I0(8`)DHF`7-P``$P=GQ+J&@4<7%@``
M$P:FY9<U``"3A26,00%O\`_GEY<``(.WQ\67=@``DX9&G!>6```#-D;"DI>(
M8Y<U``"3A86';_"/[SEQ^7*)9P;\(OA*\";T$X>'`1:1"I<7F0```SGINH,W
M"0`<XX%'[_#OW"``A66JAH4%(H47-P``$P<'AQ<V```3!@:'[_`/VOU78PGU
M"(5G8^6G"(5GP0>S!/$`(H4%9J:%[_`OW!L$!0!C200&&P44`._P+]ZJAS7!
M8W:5`#,'A0!C[.0$!6=!!PJ78V3W!`5G!0=C8X<$!6=!!R*&/H6S!>$`[_`/
MUBJ4JH<C``0`"6=A!PJ7%&,#-PD`-8^!1@7CB6(6D>)P0G2B=`)Y/H4A88*`
M(I?C_>?Z`I"!1\F_[_!/W#&_%7']<H5GHNFFY<KA6O&&[4[]4OE6]5[M8ND3
MAX<(%I$*EQ>;```#.\NK*HDNA!<E```3!05[3`"#-PL`'..!1^_P/ZFJA),%
M\`)*A>_P+_@QP1<E```3!<5YRH7O\)_(2H6%9Y.'APB*EYAC@S<+`+F/`4=C
MEP<2A6(6D>Y@3F2N9`YIZGE*>JIZ"GOJ:TIL+6&"@"*%[_"/XI<E``"3A45V
M[_#/WBJ$3=4%:I,'"@F*EY,)@0B3"H$`LXM'08-'!`"MRY'$HH4FA>_P3^(U
MS2*%[_#/[1,']?\BERJ,DP?P`F-HY``QJ",`!P!]%V,&Y`"#1@<`XXGV_B*%
M[_`OZRJ,2H7O\*_J8I4%!>-S1?6BALJ'%R<``!,')V\7)@``$P8F;X5E3H7O
M\&^]!25C>*H"`I"MP(/'!`";AR?]&X<'`)GC`\<4`#GGER4``).%16L!1>_P
MK],JA#7QW;W6A4Z%[_#/W77Q@Z>+^+UF(6?UC^.<Y_R%14Z%[_!/WG'USH47
M)0``$P7%9N_PO[5.A>_P[]+YM05,%R0``!,$Y&.-M^_PS\%!$9,%\`(BX`;D
M*H3O\,_"&<$3!!4`(H4"9*)@00%O\*_/>7&%9_UR2N@&]"+P)NP3AX<`%I$7
MF0```SDID`J7@S<)`!SC@4=1P8-'!0"JA+7/[_!OVP4%A6=CXJ<*(`"FA2*%
M[_!/K"*%[_#OV9,']?^BER*%DP;P`F-H]``1J".`!P#]%V.&IP`#QP<`XPG7
M_B``(H63!?`"[_#ON1W%8VRD!"@`[_`OQX5GH0>*EYAC@S<)`+F/`4>AYX5B
M%I&B<`)TXF1":45A@H"%9Z$'BI>88X,W"0"YCP%'G>.%8A:1HG`"=.)D0FD7
M)0``$P5E5$5A;_!/PB,`!0!EMP%%;;?O\&^Q>7$B\";L2N@&])>4``"#M(2"
MG&`^Y(%'0``7F0```SD)A**%%R4``!,%953O\*__#<421X,W"0`.![J7F&>8
MXVW3F&NA!YCC;?^BA1<E```3!>51[_`O_6G]%YD```,Y"8"BA1<E```3!651
M[_"O^PW%$D>#-PD`#@>ZEYAGF.-MTYAKH0>8XVW_HH47)0``$P7E3N_P+_EI
M_1>)```#.0E\HH47)0``$P7E3>_PK_<-Q1)'@S<)``X'NI>89YCC;=.8:Z$'
MF.-M_Z*%%R4``!,%94OO\"_U:?T7B0```SD)>**%%R4``!,%Y4KO\*_S#<42
M1X,W"0`.![J7F&>8XVW3F&NA!YCC;?^BA1<E```3!65([_`O\6G]%XD```,Y
M"72BA1<E```3!65'[_"O[PW%$D>#-PD`#@>ZEYAGF.-MTYAKH0>8XVW_HH47
M)0``$P7E1._P+^UI_1>)```#.0EPHH47)0``$P5E1._PK^L-Q1)'@S<)``X'
MNI>89YCC;=.8:Z$'F.-M_Z*%%R4``!,%Y4'O\"_I:?T7B0```SD);**%%R4`
M`!,%Y3CO\*_G#<421X,W"0`.![J7F&>8XVW3F&NA!YCC;?^BA1<E```3!64V
M[_`OY6G]%XD```,Y"6BBA1<E```3!64][_"OXPW%$D>#-PD`#@>ZEYAGF.-M
MTYAKH0>8XVW_HH47)0``$P7E.N_P+^%I_1>)```#.0EDHH47)0``$P5E.N_P
MK]\-Q1)'@S<)``X'NI>89YCC;=.8:Z$'F.-M_Z*%%R4``!,%Y3?O\"_=:?T7
MB0```SD)8**%%R4``!,%93?O\*_;#<421X,W"0`.![J7F&>8XVW3F&NA!YCC
M;?^BA1<E```3!>4T[_`OV6G]%XD```,Y"5RBA1<E```3!>4I[_"OUPW%$D>#
M-PD`#@>ZEYAGF.-MTYAKH0>8XVW_HH47)0``$P5E)^_P+]5I_:*%%R4``!,%
MY3#O\"_4JH49Q1<E```3!>4M[_!/]**%%R4``!,%A3#O\$_2JH49Q1<E```3
M!04Q[_!O\J*%%R4``!,%)3'O\&_0JH4=R1<E```3!:4@[_"/\")GG&"YCP%'
MH>,"=*)PXF1":9<E``"3A<4P%R4``!,%Q21%86_P#^ZBA1<E```3!<4M[_`/
MS*J%8=47)0``$P7%)._P+^QMO^_@?_D!$2+H!NP7A````S3$2DP`%R4``!,%
MI2(<8#[D@4?O\(_(%<&#1P4``46)QY.'!_TS-?``(F<<8+F/`4>9Y^)@0F0%
M88*``47UM^_@G_07@P```S/#3!UQ*HX#-0,`+O03`X$",O@&[/*%-OP7C@``
M`SYN1+K@ON3"Z,;L&H:#-PX`/N2!1QK@[_"OEQ,%\`_O\"^,77'!<L%G2OA.
M]%+PAN2BX";\5NQ:Z!.'AP`6D0J7%XH```,Z"D"#-PH`'..!1PE&@46JB>_@
MO^L3"?7_$U?Y0T&3LP?I`,(7P9.9CS,)^4!C10D(BH3]6AU+`4;*A4Z%[^#_
MZ&,#50E!9B$&IH5.A>_@__`!)6,$50=C?*L$814SA*0`8W:4`*F@?11C8Y0$
M(4:7A0``DX5%02*%[^`_]&WU,P4D0$J5P6>A!XJ7F&.#-PH`N8\!1YWOP6(6
MD:9@!F3B=$)YHGD">N)J0FMA88*`P7<^F>,2^?A]5?&W%R4``!,%A1?O\%_M
M%R4``!,%Q17O\)_L[^"?X$$1!N3OX!_9[^#?\Q'!"&&B8$$!@H`Y<2;T2O`&
M_!>)```#.6DPJH1,`!<E```3!244@S<)`#[D@4?O\.^M&<4B^(-'!0`JA)WC
M0G0B9X,W"0"YCP%'IH47)0``$P5%$;WCXG"B=`)Y(6%O\`_,)H5.[._@/_BJ
MB2*%[^"_]TZ5"07OX#_3(H<FAI<F``"3AJ;[ER4``).%)?PJA._@G^PB9X,W
M"0"YCP%'E>.BA4)TXFGB<*)T`GD7)0``$P5%"R%A;_"/QB+X3NSOX+_3[^!_
MTY>'``"3AZ<M`[B'`PEQ`[\'`8.^AP$#O@<"`[.'`H.X!P/*\L[NTNJ&_J+Z
M$PG!`!>*```#.BHBJHD7)@``$P:&!Y<F``"3AH;P%R<``!,'!P>7)P``DX<'
M!\+TRH47)0``$P5%[P,X"@!"]@%(`O`"_/K@]N3RZ)KLQO`RZ#;L.O0^^._P
M+YP1Q8-'!0`JA&.6!QRF]M;F[^"_PN_@?]UC!`44`&%C`004(H7OX'_G!@4%
M!>_@_\(#1@0`JH2JB@G.)H67)0``DX7E`._@?]P#1A0`!02)!&WVA``7)0``
M$P7E]2&@B&2A!`W!RH7O\(^5*H1MV8-'!0#UU^_PSYY]T2*%[^#_TBJ$$>T$
M"(!@&<B#1P0`^<<BA>_P[YQ%[8!DH01]]"*%[^"_WZJ$5H7OX#_?J9R;A$1`
M)H7OX'^ZUH<BAA<G```3!V?YER8``).&YN*7)0``DX7E^*J*[^!?TU:%DP4`
M'._@O^']5V,8]0#OX!_7&$'%1V,2]PR,&%:%[^`?PBJ$&>6*1[UF$6?UCV..
MYPB7AP``@[='$@.V"0"(8]:&ER4``).%Q?COX%^\@40R=X,W"@"YCP%'8YP'
M+/9P5G2V:A9Y]FE6:B:%MG0988*`(H7OX+_%*H2A!!W5D;<!1(&W)!"(8!G)
MRH7O\&^%`<6#1P4`A>.(9*$$??4U1>_@_ZVJA*J*%R0``!,$Y.D3!C`%;;7O
MX)_!*H2A!&'5[^#_SP8%!05AM=KB*DOOX!^I8P6K!!9KJ;^7AP``@[?'!P.V
M"0"(8]:&ER4``).%1>KOX-^QH;_O\)_.,G>#-PH`N8\!1V.:!R(BA59T]G`6
M>?9I5FH986_@?[N*1U[^$P<`')/W]Q]CA><`%FOR>PFW)H7OX+^DRH6JA!<E
M```3!:7N[^#_^:J%8P<%$`.U"0#O\._+JHMC``407H7OX!_&&PL%`(U'8]AG
M`Q,%R_]>E9<E``"3A<7K[^!?N`GMD4=C#/L6FP>[_]Z7`\<'`),'\`)C`_<6
MRH47)0``$P7%S>_@'_1%S8-'!0#-RQ,'``-CAN<*ER4``).%A=47)0``$P6%
MR^_P[Y+OX%^5*H=6AB:%ER<``).')_67)@``DX:FPY<E``"3A:7G[^`_M'U9
MQ4D=J._@G[@<06.>-P/OX/^1!20JAZ*'5H8FA1<H```3"(CQER8``).&!L"7
M)0``DX4%Y>_@G["3!0`<)H7OX/^^XP$E_5:%[^!?P::%%R4``!,%Y;KO\,^*
M)H7O\#^Y%FOR>^V[@[L)``&W7H6!1>_@W[8JB3G5[_!_IJJ)XT,%]),%9?\!
M1DJ%[^`_E!,+`0_:A4J%&4;OX%^<F4=C&_4(3E>W1T%#DX<',.,<]_`#5TL`
MD6>3AX=4XQ7W\).%Z?P!1DJ%[^!_D*`92H6BA1,&@`+OX)^8DP>``F,<]00B
MAY<G``"3AR?EER8``).&IK-6AI<E``"3A876)H4C``$2[^"_HX&W@[F)`..-
M">A.A>_@OZN-1^/WI^AQ%4Z5ER4``).%1=+OX%^>XQT%YLZ+E;T7)0``$P6%
MT>_PWY7:XE[^[^"?B:;VUN;:XE[^[^#?B#EQ(O@7A````S1$X4KP3NP&_";T
M4NBS!T0`A&.3"4$`%XD```,YB=B#QP0+SH47)0``$P4EK@,W"0`ZY`%'HXCT
M"N_@O]49Q0-'!0"3!Q`#8PGW$N_P+]*S!T0`A&,FA8U&!4:7)0``DX7%S>_@
MWYBJA!W!'&DS!T0`"&.,8Q<F```3!J;,[^`_@YQHC&/<11.7EP)C3`<0LP=$
M`(ACC48%1I<E``"3A>7*[^#_E*J$%XH``!,*"N`-P<Z%%R4``!,%Q9_OX)_-
M*H9IP9QH,P=$``ACC&/OX"_^LP=$`(1C!4:7)0``DX5EQR:%[^#?B*J%%R8`
M`!,&YL<FA>_@S_L2E!Q@SH47)0``$P4EFJ.(!PKOX+_((SBJ`#G%DP4`'._@
MGYL;!Q4`A4=C\><"Q4=C#O4`@S>*``,V"@&JAHQC%R4``!,%!<;OX`_F(F>#
M-PD`N8\!1[WGXG!"=*)T`GGB:4)J(6&"@`,UB@#O\+^>(SBJ`$7U%R4``!,%
M)<#OX*_B@T<5`..,!^SIM>_PCX68:+,'1`"JA`QCB&.1S":&[^"/\2:%[^`_
ME@6_LP=$`(AC[^!OY,VU@S>*`)!C[^"O[R&_[^!/['EQ(O`F[`;T%X0```,T
MA+VJA$P`%R4``!,%194<8#[D@4?OX#^[`<V#1P4`B<L3!P`#8X;G`('$@\<$
M`)GK(F<<8+F/`4>A[Z)P`G3B9$5A@H`FA4KH[_!/IY,%\`(JB>_@#^@9P1,)
M%0!*A>_@3_411I<E``"3A66?[^!O[1G!0FEUOR)G'&"YCP%'D>L"=$)IHG`F
MA>)D16%OX'_#2NCOX`_B$P$!U)>#``"#LX.S-`#!;B,\$2HC.($J(S21*B,P
M(2LC/#$IDPB%`Y,/A0>#MP,`(S3Q*(%'-HB3C@[P-P__``.V"`"A"$$(DU4&
M`A,7A@$3DX4!DQ*&`)-7A@("%Q->A@`35(8#`9,"$[/RX@&S]]<!$U,#`C-G
M5P`S?MX!H@7!CS-GQP$;5H8!L_7E`;/G9P!1C\V/(SCH_B,\^/[CD?C[1G_F
M?@IG8FX"<Z)X0GCB=89O$X0&(!&@LH^P8IQBNH*A!K&/L\?G`;/'QP$3EQ<`
M_8-=CP(7`9.X_AJ.=H]&@Y:.PH@NB/Z%XQC4_!!A#&D#.(4!(FZ#.(4``S,%
M`I-7M@$3%U8`-X^"6A,/GYE=CWJ>L\8%`0(7&IZ3WB@``9.3E^@!L_86`;/G
MUP%RE[/&!@$VEQ.>!P+"9A->#@*3'P<",\?%`9/?#P)QC_J6D]*_`9.>7P`M
MC\*6L^Y>`!-4)@#B8C:7DQ;F`<&.=I>3'@<"M8^3W@X",X?B`;/W]P$3U+X!
M+I>3DEX`L\?'`;/B@@"ZEP)T$Y?O`9/?+P`S9_<!EI>"%Y.2!@*YCH&3LP_D
M`9/2`@*S]M8!?IX3U+<!DY]7`+/&5@#REC/NCP#REJ)_$Y[N`9/>+@`S;MX!
M$Q0'`H(6,T?'`8&2`9"SCN\!?8^6GI.?5@"3TK8!(8]VE[/N7P!VE\)_DY[G
M`8F#L^[^`+-'W@&3$@X"`A<!DY/2`@(SCN\!]8\BGI,?5P`35+<!L\=7`/*7
M,^Z/`/*7XG\3GN8!B8(S;MX`L\;.`1.4#@*"%X&3`9"SCN\!^8Z6GI.?5P"3
MTK<!H8[VEK/N7P#VEH9ODQ[G`0F#L^[N`#-'W@&3$@X"@A:!DI/2`@(SCN\!
M?8\BGI.?5@`3U+8!,T=7`'*7,^Z/`'*7IF\3GN<!B8,S;OX`L\?.`1.4#@("
M%P&3`9"SCN\!]8^6GI,?5P"34K<!H8_VE[/N7P#VE\9ODY[F`8F"L^[>`+-&
MW@&3$@X"@A>!DY/2`@(SCN\!^8XBGI.?5P`3U+<!L\96`/*6,^Z/`/*6YF\3
M'N<!"8,S;NX`,\?.`1.4#@*"%H&2`9"SCN\!?8^6GI.?5@"3TK8!(8]VE[/N
M7P!VEX9_DY[G`8F#L^[^`+-'W@&3$@X"`A<!DY/2`@(SCN\!]8\BGI,?5P`3
M5+<!L\=7`/*7,^Z/`/*7IG\3GN8!B8(S;MX`L\;.`1.4#@*"%X&3`9"SCN\!
M^8Z6GI.?5P"3TK<!H8[VEK/N7P#VEL9_DQ[G`0F#L^[N`#-'W@&3$@X"@A:!
MDI/2`@(SCN\!?8\BGI.?5@`3U+8!,T=7`'*7,^Z/`'*7YG\3GN<!B8,S;OX`
ML\?.`1.4#@("%P&3`9"SCN\!]8^6GI,?5P"34K<!H8_VE[/N7P#VEXIODY[F
M`8F"L^[>`+-&W@&3$@X"@A>!DY/2`@(SCN\!^8XBGI.?5P`3U+<!L\96`/*6
M,^Z/`/*6JF\3'N<!"8,S;NX`,\?.`1.4#@*"%H&2`9"SCN\!?8^6GI.?5@"3
MTK8!(8]VE[/N7P!VEY.?YP'*;HF#L^__`+-'_@&3$@X"`A<!DY/2`@(SCNX!
M]8\BGI,>5P`35+<!L\=7`/*7,^Z.`/*7ZF03WB8`DY[F`8(7@9.S[LX!$]FW
M`;/&WP$3E`\"$YY7``&0LX_D`3-N+@'YCI:?H8X"'A->#@+^EO*6"GD37B<`
MDY(&`I,?YP&3T@("L^_/`3/'_@&3E`X"$YY2`+,.Z0$3W[(!@9`S;NX!?8^B
MGB6/`AX37@X"=I<3E.<!B8-REUV,L\>/`*I^$QD'`A-9"0*UC[?VV6Z3AA:Z
M$U^Y`1,>60`S;NX!MIZ"%Z:>@9,"'O:7$UX.`CZ>$Y_B`9/2(@`S;U\`RG>3
M%`X"@9"S3N0!D]*T`;/.[@""'Q.75`"3WP\",V=7`+:7@AZ3W@X"_I<"%_:7
M`9,^EY,>Z0$362D`L^XN`>IWDQ('`I/2`@*S3]\!$]FR`;//SP$"%!.>4@`!
MD#-N+@&VEX(?D]\/`J*7`A[^EQ->#@(^GI.?Y`&)@+/OGP".9Q,4#@(!D+/$
M_@$36;0!N8P"'Q,75``37P\",V<G`;:7@A2!D/J7`A>FEP&3/I<3G^(!D]<B
M`#-O_P"3$@<"KF>3T@("L\3O`1/9L@&SQ,0!@AX3GE(`D]X.`C-N+@&VEX(4
M@9#VEP(>II<37@X"/IZ3'N0!DU<D`+/N_@`3%`X"SF<!D+-$WP$36;0!N8R"
M'Q,75`"3WP\",V<G`;:7@A2!D/Z7`A>FEP&3/I>3G^(!D]<B`+/O_P"3$@<"
M[F>3T@("L\3^`1/9L@&SQ,0!`A\3GE(`$U\/`C-N+@&VEX(4@9#ZEP(>II<3
M7@X"/IX3'^0!DU<D`#-O_P`3%`X"CG<!D+/$[P$36;0!N8R"'A,75`"3W@X"
M,V<G`;:7@A2!D/:7`A>FEP&3/I>3GN(!D]<B`+/N_@"3$@<"KG>3T@("LT3?
M`1/9L@&SQ,0!@A\3GE(`D]\/`C-N+@&VEX(4@9#^EP(>II<37@X"/IZ3'^0!
MDU<D`+/O_P`3%`X"SG<!D+/$_@$36;0!N8P"'Q,75``37P\",V<G`;:7@A2!
MD/J7`A>FEP&3/I<3G^(!D]<B`#-O_P"3$@<"[G>3T@("L\3O`1/9L@&SQ,0!
M@AX3GE(`D]X.`C-N+@&VEX(4@9#VEP(>II<37@X"/IZ3'N0!DU<D`+/N_@`3
M%`X"DF<!D+-$WP$36;0!N8R"'Q,75`"3WP\",V<G`;:7@A2!D/Z7`A>FEP&3
M/I>3G^(!D]<B`+/O_P"3$@<"LF>3T@("L\3^`1/9L@&SQ,0!`A\3GE(`$U\/
M`C-N+@&VEX(4@9#ZEP(>II<37@X"/IX3'^0!DU<D`#-O_P`3%`X"TF<!D+/$
M[P$36;0!N8R"'A,75`"3W@X",V<G`;:7@A2!D/:7`A>FEP&3/I>3GN(!D](B
M`+/N7@#R9Y,4!P*!D+-"WP$3V;0!L\+"`8(?$YY4`)/?#P(S;BX!MI>"$I/2
M`@+^EP(>EI<37@X"/IZ3$N0!DU<D`+/B\@`3%`X"DG<!D+//7@`36;0!L\_O
M``(?$Q=4`!-?#P(S9R<!MI>"'Y/?#P+ZEP(7_I<!DSZ7DY_D`8F`L^^?`+)W
M$QD'`A-9"0(SS_(!DU2Y`3-/SP&"'A,>60"3W@X",VZ>`+:7`A\37P\"]I<"
M'OJ7$UX.`K..QP$3'^0!"8`S;X\`TG>3E`X"@9`SSN\!$]2T`3-.[@""$A.7
M5`"3T@("08^VEP(>$UX.`I:7`A<!DQ,4Z0'REQ-9*0`S9"0!,X[G`')WLT>/
M`+/'UP&"'Y,>#@*3W@X"D]\/`C:7@A<3V;X!@9-^EY.?7@`^EY.2Y`&SYR\!
MB8"SXI(`/I>69[-/5`"3%`\",\[/`1,?!P(37P\"@9"VEP(>DU^_`1->#@*F
MEY,67P"SYO8!$Y?N`?*7D]XN`#-GUP&VE[9NM_;&(Y,?!P(3G@<"DY<F`).'
MQ\V3WP\"L^;B``(4$UX.`K/T\@$!D+Z>L_;F`:*>Q8X3%%X`DU2^`?:6LVZ4
M`/:65F23%.\!DUXO`+/NU`$3GP(",V?7`9.2!@*3T@("LP;T`#-WQP$S]/X!
M$U\/`C:?D]2R`4&/$Y12`),6[@%ZEQ->+@`S;Y0`L^;&`7J7=F\3E`8"`9`S
M[MX``A<!D[/TC@`^GS-^7@!^GS-NG@"3'U<`DU2W`7J>,^^?`'J>EG03F>(!
M$]\B`#-OZ0&3'PX"L^;F`8(>D]\/`K-RCP`SCO0`D]X.`OF.=IZSYE8`$]F_
M`9.27P"3%.<!DUXG`#.'Q@&SYM0!,^XB`;9^<I>3D@8"D]("`C-NWP`"%P&3
MLW1?`+Z>,W[^`:*>,VZ>`!,45P"35+<!=IZS;I0`5G23E.\!D]\O`+/O]`%V
MGI,>#@*SYO8!`A^3W@X",P[T`!-?#P(S]%\`^8YZGL&.$]F^`1.47@"3%.<!
M$U\G`#.'Q@&SYN0!,VXD`79_<I<3E`8"`9`S[M\``A<!D[/TCP`^GS-^W@$6
MGS-NG@"3$E<`DU2W`7J>,^^2`)IBDY3N`9/>+@"S[M0!>IX3'PX"L^;6`8(?
M$U\/`C..\@"3WP\"L_*.`/F.?IZSYE8`$UF_`9,27P"3%.<!DU\G`#.'Q@&S
MYO0!,^XB`;IO<I>3D@8"D]("`C/NW@`"%P&3L_1>`+Z?,W[N`:*?,VZ>`!,4
M5P"35+<!?IZS;Y0`6F23%.\!$U\O`#/OY`%^GI,?#@*SYN8!@AZ3WP\",P[T
M`)/>#@(S=%\`^8YVGL&.$]F_`1.47P"3%.<!DUXG`#.'Q@&SYM0!,VXD`?IN
M<I<3E`8"`9`S;M\``A<!D[-TCP"^GC-^_@&6GC-NG@"3$E<`DU2W`7:>L^Z2
M`)IRDY3O`9/?+P"S[_0!=IZ3'@X"L^;V`0(?D]X.`C..\@`37P\"L_*/`/F.
M>IZSYE8`$]F^`9.27@"3%.<!$U\G`#.'Q@&SYN0!,^XB`3I_<I>3D@8"D]("
M`C/NWP`"%P&3L_1?`#Z?,W[>`2*?,VZ>`!,45P"35+<!>IXS;Y0`6G23E.X!
MD]XN`+/NU`%ZGA,?#@*SYM8!@A\37P\",P[T`)/?#P(S]%X`^8Y^GL&.$UF_
M`1,47P"3%.<!DU\G`#.'Q@&SYO0!,VXD`?I_<I<3E`8"`9`S[MX``A<!D[/T
MC@"^GS-^[@&6GS-NG@"3$E<`DU2W`7Z>L^^2`)YBDQ3O`1-?+P`S[^0!?IZ3
M'PX"L^;F`8(>D]\/`C..\@"3W@X"LW*/`/F.=IZ3U+\!DYY?`+/F5@"3$N<!
M"8,SY^(`\I8S[IX`OF[REI,2!P*3T@(",V[O`((6@9*S=%\`OIXS?OX!HIXS
M;IX`$Y16`)/4M@%VGK-NE`!VGEYDDY3O`9/?+P"3'@X",^[T`3-GQP$"'Y/>
M#@*S#_0`=8\S=%X`$U\/`GZ?08^3GUX`$]2^`7J7,^^/`/YD>I<3G^8!B8*S
M9M\``A<!DY.?!@*3WP\",V_>`!-9MP&^E!,45P"FDC-D)`&S=/X!,W_?`3-O
MGP`"%`&0%I^>="*?DQ(/`I/2`@(3E.X!D]XN`#-DU`&^E).>4@"3U[(!P8ZS
M[OX``AZS]^8`$UX.`I.6#@*S?O0!)IZSY]<!\I>!DKZ6DQ3G`0F#V8P3F08"
MOGZWMY@R$UD)`C-'E`"*!Y.'9QTS1^<!$QY9`!-?N0$S;NX!OIX"%_Z>`9,"
M'A->#@)VE[,.QP$3G^(!D](B`#-O7P"3F0X"7GZ3V0D",\?D`9/?N0$UCP(4
MDY99``&0L^;V`3Z>`A<BG@&3@A:!DG*7,P[7`),?Z0$362D`L^\O`9,2#@)^
M=Y/2`@*S1O\!$]2R`;/.U@&"%).64@"!D,&./I>"'I/>#@(FEX(6=I>!DKJ6
MDY[I`9/9*0"S[CX!$Y0&`@,W`2`!D+/$WP$36;0!L\3$`0(?$QY4`!-?#P(S
M;BX!/I>"%(&0>I<"'B:7$UX.`CJ>$Y_B`1/7(@`S;^\`DQ(.`@,W@2"3T@("
ML\3N`1/9L@&UC((?DY92`)/?#P*SYB8!/I>"%(&0?I>"%B:7@9*ZEI,?Y`$3
M5R0`L^_O`!.4!@(#-P$A`9"S1/\!$UFT`;/$Q`&"'A,>5`"3W@X",VXN`3Z7
M@A2!D':7`AXFEQ->#@(ZGI.>X@$3UR(`L^[N`),2#@(#-X$AD]("`K/$WP$3
MV;(!M8P"'Y.64@`37P\"L^8F`3Z7@A2!D'J7@A8FEX&2NI83'^0!$U<D`#-O
M[P`3E`8"`S<!(@&0L\3N`1-9M`&SQ,0!@A\3'E0`D]\/`C-N+@$^EX(4@9!^
MEP(>)I<37@X".IZ3G^(!$]<B`+/O[P"3$@X"`S>!(I/2`@*S1/\!$]FR`;6,
M@AZ3EE(`D]X.`K/F)@$^EX(4@9!VEX(6)I>!DKJ6DQ[D`1-7)`"S[NX`$Y0&
M`@,W`2,!D+/$WP$36;0!L\3$`0(?$QY4`!-?#P(S;BX!/I>"%(&0>I<"'B:7
M$UX.`CJ>$Y_B`1/7(@`S;^\`DQ(.`@,W@2.3T@("L\3N`1/9L@&UC((?DY92
M`)/?#P*SYB8!/I>"%(&0?I>"%B:7@9*ZEI,?Y`$35R0`L^_O`!.4!@(#-P$D
M`9"S1/\!$UFT`;/$Q`&"'A,>5`"3W@X",VXN`3Z7@A2!D':7`AXFEQ->#@(Z
MGI.>X@$3UR(`L^[N`),2#@(#-X$DD]("`K/$WP$3V;(!M8P"'Y.64@`37P\"
ML^8F`3Z7@A2!D'J7@A8FEX&2NI83'^0!$U<D`#-O[P`3E`8"`S<!)0&0L\3N
M`1-9M`&SQ,0!@A\3'E0`D]\/`C-N+@$^EX(4@9!^EP(>)I<37@X".IZ3G^(!
M$]<B`+/O[P"3$@X"`S>!)9/2`@*S1/\!$]FR`;6,@AZ3EE(`D]X.`K/F)@$^
MEX(4@9!VEX(6)I>!DKJ6DQ[D`1-7)`"S[NX`$Y0&`@,W`28!D+/$WP$36;0!
ML\3$`0(?$QY4`!-?#P(S;BX!/I>"%(&0>I<"'B:7$UX.`CJ>$Y_B`1/7(@`S
M;^\`DQ(.`@,W@2:3T@("L\3N`1/9L@&UC((?DY92`)/?#P*SYB8!/I>"%(&0
M?I>"%B:7@9*ZEI,?Y`$35R0`L^_O`!.4!@(#-P$G`9"S1/\!$UFT`;/$Q`&"
M'A,>5`"3W@X",VXN`3Z7@A2!D':7`AXFEY.>X@$37@X"D](B`+/N7@`ZG@,W
M@2>SPM\!L\;2``(?$U\/`I,2#@(^EX(6D]("`H&2>I>3E%(`$]FR`3:7$Q_D
M`8,V`2@)@#-OCP"SY"0!,\3N`2:7MI>"'P(7,T[$`0&3LI>3WP\"`AZ35K<!
M$Q97`!->#@+^EU6.\I>3EN(!D](B`+*7L^96`#,&%P%VDS.'M@!"GX(7@9.3
M%@8"DQ4#`A,6#P("%X&2@9$!D@&3'.$4Y0SQ$.V#-H$H@[<#`+6/@488Z9'O
M@S"!*P,T`2N#-($J`SD!*H,Y@2D3`0$L@H#OT`^801$3!0`(!N3OT$^2%T@`
M``,XB$BW=EU,-W?I888&MR5%9S=6,A`&!Y.&YL^3A14P$P9F1Q,'!Q\4Z2,T
M!0(C.`4"(RP%!@SA(S0%`1#M&/&B8$$!@H!=<2;\4O!6[(;DHN!*^$[T&'63
M%S8`LH2ZEQ!Y@A>!DS.WYP`JBI/6U`$H73J6,X?&`",T^@(C..H"KHI1Z5KH
M$PF*`Q,+\`-C7YL"7N16A).)"@23"XH'8W")!F-C=`?.BJ*%$P8`!$J%[]#/
M@5*%FX0$_._@?ZD3!`0$DXD)!.-,F_RB:V-O60-C]BH!LX>:`&-M^0+6A4J%
M)H;OP+_^(RR:!D)KIF`&9.)T0GFB>0)ZXFIA88*`SHKC="3[XW(Y^P*0LP>9
M`./W^OQ>Y`*0DP<`!(F?&X0'`&/4]``;A`0`$PF*`TJ58WQ5`[,'A0"SB8H`
M8^SZ`M:%(H;OP+_X@R>*!Q,'``2AGR,L^@;CG.?X4H5:Z(&<[^`_G\Z*';>S
MB8H`X_JJ_.-X-?U:Z%[D`I`Y<2+X)O1.[%+H6N`&_$KP5N0#N84"@]:%`@/7
M!0.35SD`$XN%`Y/W]P.3V88`$UJ'`)N6A@`;%X<`,P;[`"Z$L^G9`),%`/@S
M:NH`@SH$`X4G(P"V`,(90AH3!H`#JH23V0D#,P7[`!-:"@-C5?80$P<`!+L'
M]T`11V/_YQ`)1V/SYQ!CG@<.(H7OX/^46H43!H`#@47OT.^&DU>)`1/7B@$3
M60D!D]H*`2,91`<C&S0'HPA4!R,*]`:C"B0'(H4C".0&[^!?D1Q@(H7A@R.`
M]``<8,&#HX#T`!Q@H8,C@?0`'&"C@?0`'&3A@R."]``<9,&#HX+T`!QDH8,C
M@_0`'&2C@_0`'&CA@R.$]``<:,&#HX3T`!QHH8,CA?0`'&BCA?0`'&SA@R.&
M]``<;,&#HX;T`!QLH8,CA_0`'&RCA_0`''#A@R.(]``<<,&#HXCT`!QPH8,C
MB?0`''"CB?0`0G3B<*)T`GGB:4)JHFH":R%A;]`OD!V>@47OP+_X,;\C``4`
M$;<C``4`HP`%`/D7.I7CBP?N[;<C``4`HP`%`",!!0"C`04`\1<ZE0E'X^OG
M[-&_)7,O)7,```!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(``````$EN
M=&5R;F%L<SHZ4$%2.CI"3T]4`````&5X90``````+W!R;V,O)6DO)7,`````
M`"X`````````4$%27U1%35```````````%!!4E]04D]'3D%-10`````Z````
M`````"\`````````)7,E<R5S``!015),-4Q)0@``````````4$523$Q)0@!0
M15),-4]05```````````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-0
M05=.140``````%!!4E]#3$5!3@````````!005)?1$5"54<`````````4$%2
M7T-!0TA%`````````%!!4E]'3$]"04Q?1$5"54<``````````%!!4E]'3$]"
M04Q?5$U01$E2`````````%!!4E]435!$25(```````!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@``````````,0````````!L<V5E:R!F86EL
M960`````<F5A9"!F86EL960``````$Q$7TQ)0E)!4EE?4$%42`!365-414T`
M`"]T;7``````55-%4@````!54T523D%-10``````````)3`R>`````!P87(M
M`````"5S)7,E<R5S```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%!!5$@`````
M<&%R;``````N<&%R`````'-H;W)T(')E860````````E<R5S8V%C:&4M)7,E
M<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,``````````!@`
M````````<&5R;``````P`````````%!!4CHZ4&%C:V5R.CI615)324].````
M`#$N,#8S````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````
M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R
M>2`E<R!F86EL960@*&5R<FYO/25I*0H``````````"UE````````+2T`````
M``!435!$25(``%1%35!$25(`5$5-4`````!435```````&5V86P@)V5X96,@
M+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R
M=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@
M*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S
M:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,
M15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?
M<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B
M(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I
M>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM
M>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[
M("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I
M>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A
M9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I
M.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P
M*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*
M?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP
M9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.
M?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA
M;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@
M9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H
M*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D[
M"G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@
M)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!
M5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P*
M*3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@
M/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F
M("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB
M<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I
M;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE
M.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y
M<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S
M<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)
M3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N
M86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P
M("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@
M("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE
M>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R
M+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;
M7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*
M;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D[
M"FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'
M24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H
M;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T
M(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D
M(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*
M;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA
M9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN
M9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!
M1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G
M:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T
M7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L
M(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@
M)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O
M=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B
M=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F
M<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ
M93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S
M970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(
M+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P
M.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U
M:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@
M("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F
M(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO
M=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C
M<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q
M(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH
M/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@
M7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X
M="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F
M:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64[
M"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M
M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]
M/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R
M97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T
M.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]
M($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I
M;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I
M;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D
M=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?
M0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@
M=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I
M;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE
M;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP
M;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64[
M"F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@
M(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D
M=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E
M<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K
M97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA
M;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE
M(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92![
M"F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M
M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE
M?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z
M:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M
M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@
M+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?
M87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I
M.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D55
M4T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S
M(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2![
M"FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A
M;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R
M:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E
M)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T
M($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`
M861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;
M04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I
M('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@
M>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF
M="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]
M("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*
M?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I
M9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,
M)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P
M96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*
M)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD
M(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ
M)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D
M7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O
M7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@
M)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A
M<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N
M)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z
M.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E
M("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@
M;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T
M82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M
M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q
M<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR
M96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@
M9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@[
M"GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H
M"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2
M*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#
M86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D[
M"G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A
M<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A
M<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F
M.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@
M86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P
M<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF
M("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L
M97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B
M=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R
M8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X
M<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM
M>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H
M87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N
M9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V
M<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@
M:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D
M*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D
M9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@
M;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI
M)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II
M9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@
M)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H
M)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE
M+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M
M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D
M;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E
M<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*
M;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I
M;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY
M("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F
M:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D
M/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^
M("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H
M+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL
M"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S
M,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N
M="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D
M960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D
M;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N
M9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P
M87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*
M:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z
M.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D
M9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD
M:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A
M8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I
M;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F
M:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D
M(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S
M=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I
M;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE
M+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z
M.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I
M;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A
M73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI
M"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA
M;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*
M<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A
M="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB
M97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M
M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE
M;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@
M/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.
M5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M
M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO
M=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A
M9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q
M6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN
M72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT
M<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U
M-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL
M97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@
M=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER
M(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P
M(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B
M($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ
M0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z
M.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER
M92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S
M<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R
M97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A
M9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E
M('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER
M92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE
M.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q
M=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I
M<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*
M979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T[
M"F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER
M92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE
M.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/
M.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T
M9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A
M<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA
M<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-
M4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE
M<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM
M>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P
M=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R
M.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M
M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W
M=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D
M14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H
M)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92![
M"F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S
M(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA
M9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%
M(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#
M2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G
M:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B
M*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C
M:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B
M8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER
M*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`]
M(#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I
M<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R![
M"FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN
M86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE
M*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO
M<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C
M;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I
M9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I
M(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*
M<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'
M3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R
M;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%2
M7U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^
M/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D
M<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%2
M7U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@
M/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E
M='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5]
M(BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R
M96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.
M5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@
M)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L
M:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O
M9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L
M:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D
M<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD
M,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD
M97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@
M/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I
M;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D
M("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*
M8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?
M9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%
M3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E
M('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%7
M3D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L
M971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,
M14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/
M0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II
M9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*
M?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@
M>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B([
M"GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#
M+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*
M87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*
M=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X[
M"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*
M4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@
M;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R
M(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA
M;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`
M.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*
M,3L*7U]%3D1?7PH`<&5R;'AS:2YC``````````!#04-(10``B:O-[P`````!
M&P,[U````!D```!PC___I`4``/21___L````EI+__U`!``#PDO__?`$```:4
M___@`0``NI7__T`"```4EO__9`(``#R6__]X`@``()?__ZP"```BE___P`(`
M`,B8__\,`P``ZIC__RP#``#.F?__<`,``$Z=__^@`P``G)W__\0#``#BG?__
MW`,``-R>__\@!```\I[__SP$``"NG___D`0``%BD__\D!0``(*;__UP%``#$
MIO__V`4``&2[__\,!@``NKO__RP&``#LO/__D`8````````0``````````-Z
M4@`!?`$!&PP"`&`````8`````)'__Z(`````0@Y`3H$"B`26$%*2"),*E`QF
MB0:5#F;)0M)"TT+40M5"P43(0M9"#@!"#D"!`H@$B0:2"),*E`R5#I804,G5
M1-+3U$22"),*E`Q"TD+30M0````H````?````#Z1__]:`````$(.L`%&B`2)
M!H$"`D8*P4+(0LE"#@!""P```&````"H````;)'__Q8!````0@[``422"($"
M6(@$1LA0P4+20@X`0@[``8$"B`22"$*)!DJ3"@)"E`P"4M14"LA"R4+30@M(
MTT+(0LE"B`2)!I,*E`Q(R,G3U$B(!(D&DPJ4#`!<````#`$``!Z2__^T`0``
M`$(.8%"(!(D&D@B!`I,*E`R5#I80`M0*P4+(0LE"TD+30M1"U4+60@X`0@MN
MEQ*8%`)<"M="V$0+5-?81)<2F!1&U]A$EQ*8%$;70M@````@````;`$``'*3
M__]:`````$(.$$*(!$J!`FC(0L%>#@`````0````D`$``*B3__\H````````
M`#````"D`0``O)/__^0`````0@Y`4@[`0($"B`22"(D&`K(*#D!"P4+(0LE"
MTD0.`$(+```0````V`$``&R4__\"`````````$@```#L`0``6I3__Z8!````
M0@[@`5X.X"&(!(D&D@B6$($"DPJ4#)4.EQ*8%`)<"@[@`4+!0LA"R4+20M-"
MU$+50M9"UT+80@X`0@L<````.`(``+25__\B`````$(.$$B(!($"4,A"P4(.
M`$````!8`@``MI7__^0`````0@XP4@ZP()((@0*(!(D&`HH*#C!"P4+(0LE"
MTD(.`$(+5@H.,$+!0LA"R4+22@X`1`L`+````)P"``!6EO__@`,```!"#C!(
MB`2)!I((@0(#-@,*R$+!0LE"TE(.`$0+````(````,P"``"FF?__3@````!"
M#B!$B`2!`GH*P4+(0@X`0@L`%````/`"``#0F?__1@````!*#F!0@1(`0```
M``@#``#^F?__^@````!"#E!:#M"`!)((DPJ4#($"B`2)!I4.EA`"H@H.4$+!
M0LA"R4+20M-"U$+50M9"#@!""P`8````3`,``+2:__\6`````$(.$$*!`D[!
M0@X`4````&@#``"NFO__O`````!"#D!&B0:2"($":(@$1LA8P4+)0M)"#@!$
M#D"!`H@$B0:2"$23"@(^R$+30L%"R4+22@X`1`Y`@0*)!I((1(@$DPH`D```
M`+P#```6F___J@0```!.#H`#7I((DPJ4#($"B`0";(D&E0X#+`$*P4+(0M5"
MTD+30M1$R4(.`$(+`EJ6$$S68,G55LA"P4+20M-"U$(.`$0.@`.!`H@$B0:2
M"),*E`R5#I803)<21M9"UT*6$)<2`R(!"M9"UT(+`]H`UM=$EA"7$D3)U=;7
M2(D&E0Z6$)<2`#0```!0!```+)___\@!````0@Y`0H@$4I((DPJ!`HD&E`P#
M1`$*P4+(0LE"TD+30M1"#@!""P``1````(@$``"\H/__I`````!"#C!&B`2)
M!H$"`D(*P4+(0LE"#@!""T22"&P*TD(+3,A"TD+!1,E"#@!$#C"!`H@$B09"
MD@@`,````-`$``#$B?__B`$```!"#F!,@0*)!H@$D@B3"@,,`0K!0LA"R4+3
M1-)"#@!""P```#`````$!0``Y*#__Z`4````1`[`!6"!`H@$B0:2"),*`V(4
M"L%$R$3)1-)$TT0.`$(+```<````.`4``%"U__]6`````$(.$$:!`@)*P4(.
M`````&````!8!0``AK7__S(!````0@Y05(D&E`R5#H$"B`22"),*;I804)<2
M<M=@UD+!0LA"R4+20M-"U$+50@X`0@Y0@0*(!(D&D@B3"I0,E0Z6$)<23-=,
MU@)("I802`M0EA"7$@`\````O`4``%2V__^T`0```$(.0%"(!(D&DPJ4#)80
M@0*2")4.`U`!"LA"P4+)0M)"TT+40M5"UD(.`$0+````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````$`````````\`(````````!`````````/L"````````'0``
M``````!:!`````````P````````````````````-````````````````````
M&0````````"XJP```````!L`````````"``````````:`````````,"K````
M````'``````````(`````````/7^_V\`````L`(````````%`````````#@-
M````````!@````````"0`P````````H`````````>`0````````+````````
M`!@`````````%0````````````````````,`````````J*T````````"````
M`````$`%````````%``````````'`````````!<`````````"!0````````'
M`````````+`1````````"`````````"8!P````````D`````````&```````
M```>``````````@`````````^___;P`````!```(`````/G__V\`````"@``
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````/______
M____``````````!0&0```````%`9````````4!D```````!0&0```````%`9
M````````4!D```````!0&0```````%`9````````4!D```````!0&0``````
M`%`9````````4!D```````!0&0```````%`9````````4!D```````!0&0``
M`````%`9````````4!D```````!0&0```````%`9````````4!D```````!0
M&0```````%`9````````4!D```````!0&0```````%`9````````4!D`````
M``!0&0```````%`9````````4!D```````!0&0```````%`9````````4!D`
M``````!0&0```````%`9````````4!D```````!0&0```````%`9````````
M4!D```````!0&0```````%`9````````4!D```````!0&0```````%`9````
M````4!D```````!0&0```````%`9````````4!D```````!0&0```````%`9
M````````4!D```````!0&0```````%`9````````4!D```````!0&0``````
M`%`9````````R*L`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````"E!!4BYP;0H`````````````````````````
M````````````````````````````````````````````````````````````
M1T-#.B`H06QP:6YE(#$T+C(N,"D@,30N,BXP`$%E````<FES8W8``5L````$
M$`5R=C8T:3)P,5]M,G`P7V$R<#%?9C)P,E]D,G`R7V,R<#!?>FEC<W(R<#!?
M>FEF96YC96DR<#!?>FUM=6PQ<#!?>F%A;6\Q<#!?>F%L<G-C,7`P```N<VAS
M=')T86(`+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD
M>6YS>6T`+F1Y;G-T<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YT97AT`"YR;V1A
M=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?
M87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"YR:7-C
M=BYA='1R:6)U=&5S````````````````````````````````````````````
M```````````````````````````````````````````+`````0````(`````
M````<`(```````!P`@```````!H````````````````````!````````````
M````````$P````<````"`````````(P"````````C`(````````D````````
M````````````!````````````````````"8```#V__]O`@````````"P`@``
M`````+`"````````X``````````$``````````@````````````````````P
M````"P````(`````````D`,```````"0`P```````*@)````````!0````(`
M```(`````````!@`````````.`````,````"`````````#@-````````.`T`
M``````!X!````````````````````0```````````````````$`````$````
M`@````````"P$0```````+`1````````6`(````````$``````````@`````
M````&`````````!*````!````$(`````````"!0````````(%````````$`%
M````````!````!`````(`````````!@`````````3P````$````&````````
M`%`9````````4!D```````"@`P``````````````````$``````````0````
M`````%0````!````!@````````#P'````````/`<````````,"\`````````
M``````````(```````````````````!:`````0````(`````````($P`````
M```@3````````&!!```````````````````(````````````````````8@``
M``$````"`````````("-````````@(T```````#4````````````````````
M!````````````````````'`````!`````@````````!8C@```````%B.````
M````_`4```````````````````@```````````````````!Z````#@````,`
M````````N*L```````"XFP````````@````````````````````(````````
M``@`````````A@````\````#`````````,"K````````P)L````````(````
M````````````````"``````````(`````````)(````&`````P````````#(
MJP```````,B;````````X`$````````%``````````@`````````$```````
M``";`````0````,`````````J*T```````"HG0```````%@"````````````
M```````(``````````@`````````H`````$````#``````````"P````````
M`*````````!0````````````````````"````````````````````*8````(
M`````P````````!0L````````%"@````````6`````````````````````@`
M``````````````````"K`````0```#````````````````````!0H```````
M`!P````````````````````!``````````$`````````M`````,``'``````
M````````````````;*````````!F`````````````````````0``````````
M``````````$````#`````````````````````````-*@````````Q@``````
:``````````````$`````````````````````
